@@ -34,6 +34,7 @@ init_max <- log(mag)
 init_min <- log(mag) - abs(log(mag))*1.2
 limit <- 12
 limit_e <- 10
+low_var <- mag/100000
 
 eps <- eps*2
 
@@ -242,7 +243,7 @@ if((mod[1]!='d')&(mod[2]!='d')&(mod[3]!='d'))
 			beta_a <- result$par[1:n_a]
 			beta_c <- result$par[(1+n_a):(n_a+n_c)]
 			beta_e <- result$par[(1+n_a+n_c):(n_a+n_c+n_e)]
-			result <- optim(c(var_b_a,var_b_c,var_b_e), loglik_AtCtEt_epsp, gr_AtCtEt_epsp, pheno_m = pheno_m, pheno_d = pheno_d, B_des_a_m=B_des_a_m, B_des_a_d=B_des_a_d, B_des_c_m=B_des_c_m, B_des_c_d=B_des_c_d, B_des_e_m=B_des_e_m, B_des_e_d=B_des_e_d, beta_a=beta_a, beta_c=beta_c, beta_e = beta_e, D_a=D_a, D_c=D_c, D_e=D_e, lower = rep(1e-8,3), upper = rep(20,3), method = "L-BFGS-B", control=list(maxit = 3000))
+			result <- optim(c(var_b_a,var_b_c,var_b_e), loglik_AtCtEt_epsp, gr_AtCtEt_epsp, pheno_m = pheno_m, pheno_d = pheno_d, B_des_a_m=B_des_a_m, B_des_a_d=B_des_a_d, B_des_c_m=B_des_c_m, B_des_c_d=B_des_c_d, B_des_e_m=B_des_e_m, B_des_e_d=B_des_e_d, beta_a=beta_a, beta_c=beta_c, beta_e = beta_e, D_a=D_a, D_c=D_c, D_e=D_e, lower = rep(low_var,3), upper = rep(20,3), method = "L-BFGS-B", control=list(maxit = 3000), hessian=TRUE)
       
 		}else
 		{	
@@ -271,7 +272,7 @@ if((mod[1]!='d')&(mod[2]!='d')&(mod[3]!='d'))
 			
 			betas <- rbind(betas,c(beta_a,beta_c,beta_e))
 
-			low_a <- low_c <- low_e <- 1e-8
+			low_a <- low_c <- low_e <- low_var
 			upp_a <- upp_c <- upp_e <- 20
 			if((mod[1]=='l')|(mod[1]=='c'))
 			{low_a <- upp_a <- lower}
@@ -281,7 +282,6 @@ if((mod[1]!='d')&(mod[2]!='d')&(mod[3]!='d'))
 			{low_e <- upp_e <- lower}
 		
 			result <- optim(c(var_b_a,var_b_c,var_b_e), loglik_AtCtEt_epsp, gr_AtCtEt_epsp, pheno_m = pheno_m, pheno_d = pheno_d, B_des_a_m=B_des_a_m, B_des_a_d=B_des_a_d, B_des_c_m=B_des_c_m, B_des_c_d=B_des_c_d, B_des_e_m=B_des_e_m, B_des_e_d=B_des_e_d, beta_a=beta_a, beta_c=beta_c, beta_e=beta_e, D_a=D_a, D_c=D_c, D_e=D_e, lower = c(low_a, low_c, low_e), upper = c(upp_a, upp_c, upp_e), method = "L-BFGS-B", control=list(maxit = 3000), hessian=TRUE)	
-	
 		}
 		vars <- rbind(vars, result$par)
     hessians <- rbind(hessians, c(result$hessian))
@@ -327,7 +327,7 @@ if((mod[1]!='d')&(mod[2]!='d')&(mod[3]!='d'))
 	    		beta_a <- result$par[1:n_a]
 	    		beta_c <- result$par[(1+n_a):(n_a+n_c)]
 	    		beta_e <- result$par[(1+n_a+n_c):(n_a+n_c+n_e)]
-	    		result <- optim(c(var_b_a,var_b_c,var_b_e), loglik_AtCtEt_epsp, gr_AtCtEt_epsp, pheno_m = pheno_m, pheno_d = pheno_d, B_des_a_m=B_des_a_m, B_des_a_d=B_des_a_d, B_des_c_m=B_des_c_m, B_des_c_d=B_des_c_d, B_des_e_m=B_des_e_m, B_des_e_d=B_des_e_d, beta_a=beta_a, beta_c=beta_c, beta_e = beta_e, D_a=D_a, D_c=D_c, D_e=D_e, lower = rep(1e-10,3), upper = rep(20,3), method = "L-BFGS-B", control=list(maxit = 3000))
+	    		result <- optim(c(var_b_a,var_b_c,var_b_e), loglik_AtCtEt_epsp, gr_AtCtEt_epsp, pheno_m = pheno_m, pheno_d = pheno_d, B_des_a_m=B_des_a_m, B_des_a_d=B_des_a_d, B_des_c_m=B_des_c_m, B_des_c_d=B_des_c_d, B_des_e_m=B_des_e_m, B_des_e_d=B_des_e_d, beta_a=beta_a, beta_c=beta_c, beta_e = beta_e, D_a=D_a, D_c=D_c, D_e=D_e, lower = rep(low_var,3), upper = rep(20,3), method = "L-BFGS-B", control=list(maxit = 3000), hessian=TRUE)
       
 	    	}else
 	    	{	
@@ -356,7 +356,7 @@ if((mod[1]!='d')&(mod[2]!='d')&(mod[3]!='d'))
 			
 	    		betas_r <- rbind(betas_r,c(beta_a,beta_c,beta_e))
 
-	    		low_a <- low_c <- low_e <- 1e-8
+	    		low_a <- low_c <- low_e <- low_var
 	    		upp_a <- upp_c <- upp_e <- 20
 	    		if((mod[1]=='l')|(mod[1]=='c'))
 	    		{low_a <- upp_a <- lower}
